@@ -6,10 +6,11 @@
 #' @return A data.frame object with a new column for predicted values
 #' @seealso \code{\link{fit_model}} \code{\link{extract_model_info}}
 #' @examples 
-#' iris1 <- iris[1:50,]
-#' iris2 <- iris[51:100,]
-#' lm_model <- fit_model(iris1,"Sepal.Length","Sepal.Width","lm") 
-#' head(add_model_predictions(lm_model,iris1,iris2))
+#' data("yields", package="manymodelr")
+#' yields1 <- yields[1:50,]
+#' yields2<- yields[51:100,]
+#' lm_model <- fit_model(yields1,"weight","height","lm") 
+#' head(add_model_predictions(lm_model,yields1,yields2))
 #' @export
 add_model_predictions<- function(model=NULL,old_data=NULL, new_data=NULL){
   UseMethod("add_model_predictions")
@@ -33,10 +34,11 @@ add_model_predictions<- function(model=NULL,old_data=NULL, new_data=NULL){
 #' @inheritParams add_model_predictions
 #' @return A data.frame object with residuals added.
 #' @examples 
-#' iris1 <- iris[1:50,]
-#' iris2 <- iris[51:100,]
-#' lm_model <- fit_model(iris1,"Sepal.Length","Sepal.Width","lm") 
-#' head(add_model_residuals(lm_model,iris1))
+#' data("yields", package="manymodelr")
+#' yields1 <- yields[1:50,]
+#' yields2 <- yields[51:100,]
+#' lm_model <- fit_model(yields1,"weight","height","lm") 
+#' head(add_model_residuals(lm_model, yields2))
 #' @export
 add_model_residuals <- function(model=NULL, old_data=NULL){
 UseMethod("add_model_residuals")
@@ -44,9 +46,21 @@ UseMethod("add_model_residuals")
 }
 #' @export
 add_model_residuals <- function(model=NULL, old_data=NULL){
-  if(any(is.null(model), is.null(old_data))) stop("Both model and old_data are required.")
-  old_data$residuals <- residuals(model)
-  old_data
+  if(any(is.null(model), is.null(old_data))){
+    stop("Both model and old_data are required.")
+  }
+
+if (!is.data.frame(old_data)){
+  warning(paste0("Force converting old_data from ", typeof(old_data),
+                 "to a data.frame"))
+          old_data <- as.data.frame(old_data)
+}
+old_data$residuals <- residuals(model)
+
+old_data
+  
+
+ 
 }
 
 
