@@ -30,20 +30,20 @@
 #' @param legend_labels Text to use for the legend labels. Defaults to the default
 #' labels produced by the plot method.
 #' @param legend_title Title to use for the legend.
-#' @param signif_cutoff Numeric. If show_signif is TRUE, this defines the cutoff point for significance. Defaults to 
-#' 0.05. 
+#' @param signif_cutoff Numeric. If show_signif is TRUE, this defines the cutoff point for significance. Defaults to
+#' 0.05.
 #' @param signif_size Numeric. Defines size of the significance stars.
-#' @param signif_col  Character. Defines the col for the significance stars. 
+#' @param signif_col  Character. Defines the col for the significance stars.
 #' @param ... Other arguments to get_var_corr_
 #' @details
 #' This function uses `ggplot2` backend. `ggplot2` is thus required for the plots to work.
 #' Since the correlations are obtained by `get_var_corr_`, the default is to omit correlation between a variable and itself. Therefore
-#' blanks in the plot would indicate a correlation of 1. 
+#' blanks in the plot would indicate a correlation of 1.
 #' @return A `ggplot2` object showing the correlations plot.
 #' @examples
 #' plot_corr(mtcars,show_which = "corr",
 #' round_values = TRUE,
-#' round_which = "correlation",decimals = 2,x="other_var", 
+#' round_which = "correlation",decimals = 2,x="other_var",
 #' y="comparison_var",plot_style = "circles",width = 1.1,
 #' custom_cols = c("green","blue","red"),colour_by = "correlation")
 
@@ -74,14 +74,14 @@ plot_corr <- function(df,
                                       "gray34"),
                       legend_labels = waiver(),
                       legend_title = waiver(),
-                      
+
                       signif_cutoff=0.05,
                       signif_size = 7,
                       signif_col = "gray13",
-                      
-                      
-                      
-                      
+
+
+
+
                       ...) {
   UseMethod("plot_corr")
 }
@@ -100,7 +100,7 @@ plot_corr <- function(df,
                       show_which = "corr",
                       size = 12.6,
                       value_angle = 360,
-                      
+
                       shape = 16,
                       value_size = 3.5,
                       value_col = "black",
@@ -112,29 +112,29 @@ plot_corr <- function(df,
                        signif_cutoff=0.05,
                        signif_size = 7,
                        signif_col ="gray13",
-                      
-                      
-                      
-                      
+
+
+
+
                       ...) {
-  
+
   df <- get_var_corr_(df,...)
- 
-  
+
+
 #since R 4.0.0?
 
 stopifnot("plot_style must be one of circles or squares"= plot_style %in% c("circles","squares"))
-  
-  
+
+
 
 # Basic plot
 if (!is.null(round_which)){
   # check that the column actually exists
   if(!round_which %in% names(df)) stop("round_which must exist in get_var_corr_(df)")
-  
+
   df[[round_which]] <- round(df[[round_which]],decimals)
-  
-  
+
+
 }
 # For use with `.data`
 colour_by_string <- colour_by
@@ -142,18 +142,19 @@ if (is.null(colour_by)) {
     warning("Using correlation in colour_by")
     colour_by <- df$correlation
     colour_by_string <- "correlation"
-    
+
   }
 
- 
+
   if(is.null(legend_title)){
     warning("Using colour_by for the legend title.")
     legend_title <- colour_by_string
   }
-  
 
 
-    base_plot <- ggplot2::ggplot(data = df, ggplot2::aes_string(x = x, y = y))
+
+    base_plot <- ggplot2::ggplot(data = df, ggplot2::aes(x = !!dplyr::sym(x) ,
+                                                         y = !!dplyr::sym(y)))
     base_plot_final <- base_plot +
       geom_point(size = size,
                  aes_string(col = colour_by),
@@ -164,11 +165,11 @@ if (is.null(colour_by)) {
                             labels=legend_labels)+
       labs(x = xlabel, y = ylabel, title = title,
            color=legend_title)
-   
+
   if (plot_style == "squares") {
     base_plot_final <- base_plot +
       geom_tile(size = size,
-                aes_string(fill = colour_by),
+                aes(fill = !!dplyr::sym(colour_by)),
                 width = width) +
       scale_fill_gradient2(low = custom_cols[1],
                            mid = custom_cols[2],
@@ -177,19 +178,19 @@ if (is.null(colour_by)) {
       labs(x = xlabel, y = ylabel, title = title,
            fill=legend_title)
   }
-  
- 
-    
-    
-    
+
+
+
+
+
     # set basic colours
-    
+
     # Themes
     # can override with theme
     # No need to set default(imho)
-    # if useing p values,format 
+    # if useing p values,format
     # 2show || !2show : That is the question -----> p_value signif
-    
+
     switch(show_which,
            corr= {
              base_plot_final <-base_plot_final +
@@ -199,7 +200,7 @@ if (is.null(colour_by)) {
                  angle = value_angle,
                  size = value_size
                )
-             
+
            },
            signif={
              base_plot_final <- base_plot_final +
@@ -208,22 +209,22 @@ if (is.null(colour_by)) {
                          size=signif_size,
                          color=signif_col)+
                labs(title="Significance Plot")
-             
+
            })
 
-  
-  
+
+
  base_plot_final +
     theme_minimal()+
-   
+
    theme(
       plot.title = element_text(hjust = title_just),
       panel.background = element_blank()
-    ) 
-   
-  
+    )
+
+
+
+
+
 
-  
-  
-  
 }
